# `kbase_report_state`

[![PyPI Version][pypi-image]][pypi-url]
[![Build Status][build-image]][build-url]
[![Code Coverage][coverage-image]][coverage-url]
[![Code Quality][quality-image]][quality-url]

<!-- Badges -->

[pypi-image]: https://img.shields.io/pypi/v/kbase_report_state
[pypi-url]: https://pypi.org/project/kbase_report_state/
[build-image]: https://github.com/kbaseIncubator/kbase_report_state/actions/workflows/build.yml/badge.svg
[build-url]: https://github.com/kbaseIncubator/kbase_report_state/actions/workflows/build.yml
[coverage-image]: https://codecov.io/gh/kbaseIncubator/kbase_report_state/branch/main/graph/badge.svg
[coverage-url]: https://codecov.io/gh/kbaseIncubator/kbase_report_state
[quality-image]: https://img.shields.io/lgtm/grade/python/g/kbaseIncubator/kbase_report_state.svg
[quality-url]: https://lgtm.com/projects/g/kbaseIncubator/kbase_report_state/context:python

## API to Save KBase report state.
